@@ -1,8 +1,8 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2022 Damien GUEHO
+Copyright: Copyright (C) 2023 Damien GUEHO
 License: Public Domain
-Version: 23
+Version: 24
 Date: April 2022
 Python: 3.7.7
 """
@@ -36,7 +36,7 @@ class OKID:
 
 class OKIDWithObserver:
     def __init__(self, input_signal, output_signal, **kwargs):
-        self.observer_markov_parameters, self.y, self.U = observerKalmanIdentificationAlgorithmWithObserver(input_signal, output_signal, **kwargs)
+        self.observer_markov_parameters, self.U, self.y = observerKalmanIdentificationAlgorithmWithObserver(input_signal, output_signal, **kwargs)
         self.markov_parameters = getMarkovParametersFromObserverMarkovParameters(self.observer_markov_parameters, **kwargs)
         self.observer_gain_markov_parameters = getObserverGainMarkovParametersFromObserverMarkovParameters(self.observer_markov_parameters, **kwargs)
 
