@@ -1,9 +1,9 @@
 """
 Author: Damien GUEHO
-Copyright: Copyright (C) 2021 Damien GUEHO
+Copyright: Copyright (C) 2023 Damien GUEHO
 License: Public Domain
-Version: 20
-Date: November 2021
+Version: 24
+Date: April 2022
 Python: 3.7.7
 """
 
@@ -12,6 +12,25 @@ import numpy as np
 
 
 def getObserverGainMarkovParametersFromObserverMarkovParameters(observer_markov_parameters, **kwargs):
+    """
+    Purpose:
+
+
+    Parameters:
+        -
+
+    Returns:
+        -
+
+    Imports:
+        -
+
+    Description:
+
+
+    See Also:
+        -
+    """
 
     # Dimensions
     output_dimension, input_dimension = observer_markov_parameters[0].shape
